@@ -31,7 +31,7 @@
 #define PETSC_HAVE_CXX_DIALECT_CXX11 1
 #define PETSC_HAVE_CXX_DIALECT_CXX14 1
 #define PETSC_HAVE_CXX_DIALECT_CXX17 1
-#define PETSC_HAVE_DEVICE 1
+#define PETSC_HAVE_CXX_DIALECT_CXX20 1
 #define PETSC_HAVE_DLADDR 1
 #define PETSC_HAVE_DLCLOSE 1
 #define PETSC_HAVE_DLERROR 1
@@ -61,15 +61,12 @@
 #define PETSC_HAVE_GETRUSAGE 1
 #define PETSC_HAVE_GSL 1
 #define PETSC_HAVE_HDF5 1
-#define PETSC_HAVE_HWLOC 1
 #define PETSC_HAVE_HYPRE 1
 #define PETSC_HAVE_IMMINTRIN_H 1
 #define PETSC_HAVE_INTTYPES_H 1
 #define PETSC_HAVE_ISINF 1
 #define PETSC_HAVE_ISNAN 1
 #define PETSC_HAVE_ISNORMAL 1
-#define PETSC_HAVE_KOKKOS 1
-#define PETSC_HAVE_KOKKOS_WITHOUT_GPU 1
 #define PETSC_HAVE_LGAMMA 1
 #define PETSC_HAVE_LIBJPEG 1
 #define PETSC_HAVE_LINUX 1
@@ -109,9 +106,8 @@
 #define PETSC_HAVE_NETINET_IN_H 1
 #define PETSC_HAVE_NO_FINITE_MATH_ONLY 1
 #define PETSC_HAVE_OPENMPI 1
-#define PETSC_HAVE_PACKAGES ":amd:blaslapack:cholmod:fftw3:gsl:hdf5:hwloc:hypre:klu:kokkos:libjpeg:mathlib:metis:mpi:mumps:netcdf:parmetis:pastix:pthread:ptscotch:regex:scalapack:spqr:superlu:superlu_dist:triangle:umfpack:x11:yaml:zfp:zlib:zoltan:"
+#define PETSC_HAVE_PACKAGES ":amd:blaslapack:cholmod:fftw3:gsl:hdf5:hypre:klu:libjpeg:mathlib:metis:mpi:mumps:netcdf:parmetis:pthread:ptscotch:regex:scalapack:spqr:superlu:superlu_dist:umfpack:yaml:zfp:zlib:"
 #define PETSC_HAVE_PARMETIS 1
-#define PETSC_HAVE_PASTIX 1
 #define PETSC_HAVE_PETSC4PY 1
 #define PETSC_HAVE_POPEN 1
 #define PETSC_HAVE_POSIX_MEMALIGN 1
@@ -130,6 +126,7 @@
 #define PETSC_HAVE_RTLD_LOCAL 1
 #define PETSC_HAVE_RTLD_NOW 1
 #define PETSC_HAVE_SCALAPACK 1
+#define PETSC_HAVE_SCOTCH_PARMETIS_V3_NODEND 1
 #define PETSC_HAVE_SETJMP_H 1
 #define PETSC_HAVE_SHMGET 1
 #define PETSC_HAVE_SLEEP 1
@@ -158,17 +155,14 @@
 #define PETSC_HAVE_TGAMMA 1
 #define PETSC_HAVE_TIME 1
 #define PETSC_HAVE_TIME_H 1
-#define PETSC_HAVE_TRIANGLE 1
 #define PETSC_HAVE_UNAME 1
 #define PETSC_HAVE_UNISTD_H 1
 #define PETSC_HAVE_USLEEP 1
 #define PETSC_HAVE_VA_COPY 1
 #define PETSC_HAVE_VSNPRINTF 1
-#define PETSC_HAVE_X 1
 #define PETSC_HAVE_XMMINTRIN_H 1
 #define PETSC_HAVE_YAML 1
 #define PETSC_HAVE_ZFP 1
-#define PETSC_HAVE_ZOLTAN 1
 #define PETSC_HDF5_HAVE_PARALLEL 1
 #define PETSC_HDF5_HAVE_SZLIB 1
 #define PETSC_HDF5_HAVE_ZLIB 1
